/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2005-01-20
 * Description : a digiKam image plugin to add a border
 *               around an image.
 *
 * Copyright 2005-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef IMAGEPLUGIN_BORDER_H
#define IMAGEPLUGIN_BORDER_H

// Digikam includes.

#include "imageplugin.h"
#include "digikam_export.h"

class TDEAction;

class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_Border : public Digikam::ImagePlugin
{
    Q_OBJECT
  

public:

    ImagePlugin_Border(TQObject *parent, const char* name,
                       const TQStringList &args);
    ~ImagePlugin_Border();

    void setEnabledActions(bool enable);

private slots:

    void slotBorder();

private:

    TDEAction *m_borderAction;
};

#endif /* IMAGEPLUGIN_BORDER_H */
